package com.zhibao.crm.utils;

import com.jfinal.kit.Prop;
import com.jfinal.kit.PropKit;
import com.jfinal.plugin.activerecord.Record;
import com.jfinal.plugin.redis.Redis;
import com.zhibao.crm.common.config.JfinalConfig;
import com.zhibao.crm.common.constant.BaseConstant;
import com.zhibao.crm.erp.admin.entity.AdminUser;
import com.zhibao.mobile.entity.MobileMember;
import java.net.InetAddress;
import java.util.Date;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.codec.digest.DigestUtils;

public class BaseUtil {

   private static ThreadLocal threadLocal = new ThreadLocal();
   public static final String REGEX_ALL_BRACKETS = "\\<.*?\\>|\\(.*?\\)|\\（.*?\\）|\\[.*?\\]|\\【.*?\\】|\\{.*?\\}";


   public static boolean isDevelop() {
      return JfinalConfig.prop.getBoolean("jfinal.devMode", Boolean.TRUE).booleanValue();
   }

   public static boolean isWindows() {
      return System.getProperty("os.name").toLowerCase().contains("windows");
   }

   public static String sign(String key, String salt) {
      return DigestUtils.md5Hex((key + "erp" + salt).getBytes());
   }

   public static boolean verify(String key, String salt, String sign) {
      System.out.println(sign(key, salt));
      return sign.equals(sign(key, salt));
   }

   public static String getDate() {
      return cn.hutool.core.date.DateUtil.format(new Date(), "yyyyMMdd");
   }

   public static String getIpAddress() {
      Prop prop = PropKit.use("config/undertow.txt");

      try {
         if(isDevelop()) {
            return "http://" + InetAddress.getLocalHost().getHostAddress() + ":" + prop.get("undertow.port", "8080") + "/";
         }
      } catch (Exception var2) {
         var2.printStackTrace();
      }

      return BaseConstant.BASE_PATH;
   }

   public static String getLoginAddress(HttpServletRequest request) {
      String ip = request.getHeader("x-forwarded-for");
      if(ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
         ip = request.getHeader("Proxy-Client-IP");
      }

      if(ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
         ip = request.getHeader("WL-Proxy-Client-IP");
      }

      if(ip == null || ip.length() == 0 || "unknown".equalsIgnoreCase(ip)) {
         ip = request.getRemoteAddr();
      }

      return ip.contains(",")?ip.split(",")[0]:ip;
   }

   public static String getLoginAddress() {
      return getLoginAddress(getRequest());
   }

   public static void setRequest(HttpServletRequest request) {
      threadLocal.set(request);
   }

   public static HttpServletRequest getRequest() {
      return (HttpServletRequest)threadLocal.get();
   }

   public static AdminUser getUser() {
      return (AdminUser)Redis.use().get(getToken());
   }

   public static AdminUser getUserByToken(String token) {
      return (AdminUser)Redis.use().get(token);
   }

   public static MobileMember getMobileByToken(String token) {
      return (MobileMember)Redis.use().get(token);
   }

   public static MobileMember getMobileUser() {
      return getMobileToken() == null?null:(MobileMember)Redis.use().get(getMobileToken());
   }

   public static Long getUserId() {
      try {
         return getUser().getUserId();
      } catch (Exception var1) {
         var1.printStackTrace();
         return Long.valueOf(3L);
      }
   }

   public static void removeThreadLocal() {
      threadLocal.remove();
   }

   public static String getToken() {
      return getToken(getRequest());
   }

   public static Record getBusiness() {
      return (Record)Redis.use().get(getBusinessToken(getRequest()));
   }

   public static String getBusinessToken(HttpServletRequest request) {
      return request.getHeader("Business-Token") != null?request.getHeader("Business-Token"):getCookieValue(request, "Business-Token");
   }

   public static String getMobileToken() {
      return getMobileToken(getRequest());
   }

   public static String getToken(HttpServletRequest request) {
      return request.getHeader("Admin-Token") != null?request.getHeader("Admin-Token"):getCookieValue(request, "Admin-Token");
   }

   public static String getMobileToken(HttpServletRequest request) {
      return request.getHeader("Mobile-Token") != null?request.getHeader("Mobile-Token"):getCookieValue(request, "Mobile-Token");
   }

   public static String getCookieValue(HttpServletRequest request, String name) {
      String cookieValue = "";
      Cookie[] cookies = request.getCookies();
      if(cookies != null) {
         Cookie[] var4 = cookies;
         int var5 = cookies.length;

         for(int var6 = 0; var6 < var5; ++var6) {
            Cookie cookie = var4[var6];
            if(cookie.getName().equals(name)) {
               cookieValue = cookie.getValue();
               break;
            }
         }
      }

      return cookieValue;
   }

   public static void main(String[] args) {
   }

}
